package nl.dragontamerfred.YRPerks.GUI;

import nl.dragontamerfred.YRPerks.Config;
import nl.dragontamerfred.YRPerks.PerkManager;
import nl.dragontamerfred.YRPerks.Types.ClassData;
import nl.dragontamerfred.YRPerks.Types.Classs;
import nl.dragontamerfred.YRPerks.Types.Level;
import nl.dragontamerfred.YRPerks.Utils;
import org.bukkit.Bukkit;
import org.bukkit.ChatColor;
import org.bukkit.Material;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.event.inventory.InventoryCloseEvent;
import org.bukkit.inventory.Inventory;
import org.bukkit.inventory.InventoryView;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.UUID;

public class MainGui  implements Listener {

    public static HashMap<UUID, InventoryView> openInvs = new HashMap<>();
    public static HashMap<UUID, UUID> staffViewing = new HashMap<>();

    public void open(Player player, Player toShow) {
        Inventory inv = Bukkit.createInventory(null, 3 * 9, Config.INVENTORY_MAIN_NAME);

        // Class item
        Classs classs = PerkManager.getSelectedClassForPlayer(player.getUniqueId());
        ItemStack classItem = new ItemStack(classs.material, 1, classs.damage);
        ItemMeta classsMeta = classItem.getItemMeta();
        classsMeta.setDisplayName(classs.name);
        classsMeta.setLore(classs.description);
        classItem.setItemMeta(classsMeta);

        // Level 1-8
        ClassData data = PerkManager.getClassDataForPlayer(player.getUniqueId(), classs.id);
        int level = 1;
        int subClass = 0;
        LinkedList<Level> levels = classs.levels;
        if (data != null) {
            level = data.level;
            subClass = data.subClass;
        }
        ItemStack level1 = getLevelStack(levels.get(0), true);
        ItemStack level2 = getLevelStack(levels.get(1), level >= 2);
        ItemStack level3 = getLevelStack(levels.get(2), level >= 3);
        ItemStack level4 = getLevelStack(levels.get(3), level >= 4);
        ItemStack level5 = getLevelStack(levels.get(4), level >= 5);
        ItemStack level6 = null;
        ItemStack level7 = null;
        ItemStack level8 = null;

        if (subClass >= 1) {
            LinkedList<Level> subLevels = subClass == 1 ? classs.subClassOne.levels : classs.subClassTwo.levels;
            level6 = getLevelStack(subLevels.get(0), level >= 6);
            level7 = getLevelStack(subLevels.get(1), level >= 7);
            level8 = getLevelStack(subLevels.get(2), level >= 8);
        }

        // perks 1-5
        ItemStack perk1 = Utils.createPerkItemStack(PerkManager.getPerkById(data == null ? "no-perk" : data.perkOne));
        ItemStack perk2 = Utils.createPerkItemStack(PerkManager.getPerkById(data == null ? "no-perk" : data.perkTwo));
        ItemStack perk3 = Utils.createPerkItemStack(PerkManager.getPerkById(data == null ? "no-perk" : data.perkThree));
        ItemStack perk4 = Utils.createPerkItemStack(PerkManager.getPerkById(data == null ? "no-perk" : data.perkFour));
        ItemStack perk5 = Utils.createPerkItemStack(PerkManager.getPerkById(data == null ? "no-perk" : data.perkFive));

        // 0  1  2  3  4  5  6  7  8
        // 9  10 11 12 13 14 15 16 17
        // 18 19 20 21 22 23 24 25 26
        // 27 28 29 30 31 32 33 34 35
        // 36 37 38 39 40 41 42 43 44
        // 45 46 47 48 49 50 51 52 53

        // Class item
        inv.setItem(4, classItem);

        // Level items
        inv.setItem(11, level1);
        inv.setItem(12, level2);
        inv.setItem(13, level3);
        inv.setItem(14, level4);
        inv.setItem(15, level5);

        if (level6 != null)
            inv.setItem(21, level6);
        if (level7 != null)
            inv.setItem(22, level7);
        if (level8 != null)
            inv.setItem(23, level8);

        // Perk items
        inv.setItem(38, perk1);
        inv.setItem(39, perk2);
        inv.setItem(40, perk3);
        inv.setItem(41, perk4);
        inv.setItem(42, perk5);

        toShow.closeInventory();
        openInvs.put(toShow.getUniqueId(), toShow.openInventory(inv));
        staffViewing.put(toShow.getUniqueId(), player.getUniqueId());
    }

    private static ItemStack getLevelStack(Level level, boolean unlocked) {
        ItemStack levelStack = new ItemStack(Material.STAINED_GLASS_PANE, 1, unlocked ? (short) 14 : (short) 15);
        ItemMeta levelMeta = levelStack.getItemMeta();
        levelMeta.setDisplayName(level.name);
        List<String> lore = level.description;
        levelMeta.setLore(lore);
        levelStack.setItemMeta(levelMeta);
        return levelStack;
    }

    @EventHandler
    public void on(InventoryCloseEvent event) {
        if (openInvs.get(event.getPlayer().getUniqueId()) == event.getView()) {
            staffViewing.remove(event.getPlayer().getUniqueId());
            openInvs.remove(event.getPlayer().getUniqueId());
        }
    }

    @EventHandler
    public void on(InventoryClickEvent event) {
        if (openInvs.get(event.getWhoClicked().getUniqueId()) == event.getView()) {
            Player player = ((Player) event.getWhoClicked());
            event.setCancelled(true);
            if (staffViewing.getOrDefault(player.getUniqueId(), null) != player.getUniqueId())
                return;
            switch (event.getSlot()) {
                case 4: {
                    player.sendMessage("This should have opened the class gui.");
                    //TODO open class change gui
                    break;
                }
                case 38: {
                    player.sendMessage("This should have opened the perk gui.");
                    new PerkGui().open(player, 1);
                    break;
                }
                case 39: {
                    player.sendMessage("This should have opened the perk gui.");
                    new PerkGui().open(player, 2);
                    break;
                }
                case 40: {
                    player.sendMessage("This should have opened the perk gui.");
                    new PerkGui().open(player, 3);
                    break;
                }
                case 41: {
                    player.sendMessage("This should have opened the perk gui.");
                    new PerkGui().open(player, 4);
                    break;
                }
                case 42: {
                    player.sendMessage("This should have opened the perk gui.");
                    new PerkGui().open(player, 5);
                    break;
                }
            }
        }
    }
}
