package nl.dragontamerfred.YRPerks;

import nl.dragontamerfred.YRPerks.Classes.ClassArcher;
import nl.dragontamerfred.YRPerks.Classes.ClassNone;
import nl.dragontamerfred.YRPerks.Commands.CommandPerks;
import nl.dragontamerfred.YRPerks.GUI.AdminGui;
import nl.dragontamerfred.YRPerks.GUI.MainGui;
import nl.dragontamerfred.YRPerks.GUI.PerkGui;
import nl.dragontamerfred.YRPerks.Perks.*;
import org.bukkit.plugin.java.JavaPlugin;

import java.io.File;
import java.util.logging.Logger;

public final class YRPerks extends JavaPlugin {

    public static YRPerks plugin;
    public static Logger logger = Logger.getLogger("minecraft");

    @Override
    public void onEnable() {
        plugin = this;
        PerkManager.init(new File(getDataFolder(), "playerData.db"));

        // Load config, messages and perk config files
        logger.info("Loading config");
        Config.load(new File(getDataFolder(), "config.yml"));
        logger.info("Loading messages");
        Messages.load(new File(getDataFolder(), "messages.yml"));
        logger.info("Loading perk settings");
        PerkSettings.load(new File(getDataFolder(), "perks.yml"));

        // Register listeners
        getServer().getPluginManager().registerEvents(new MainGui(), this);
        getServer().getPluginManager().registerEvents(new PerkGui(), this);
        getServer().getPluginManager().registerEvents(new AdminGui(), this);

        // Register commands
        getCommand("perks").setExecutor(new CommandPerks());

        // Register classes
        logger.info("Loading classes");
        PerkManager.registerClass(new ClassNone());
        PerkManager.registerClass(new ClassArcher());

        // Register perks
        logger.info("Loading perks");
        PerkManager.registerPerk(new PerkNone());
        // Archer perks
        PerkManager.registerPerk(new PerkArchersAgility());
        PerkManager.registerPerk(new PerkTrustyBow());
        PerkManager.registerPerk(new PerkBlessingOfTheGoddess());
        PerkManager.registerPerk(new PerkGoldenHeart());
        PerkManager.registerPerk(new PerkArrowSpawn());

    }

    @Override
    public void onDisable() {
        // Plugin shutdown logic
    }
}
